@@ -5,12 +5,12 @@ mod srtcp_test;
 #[cfg(test)]
 mod srtp_test;
 
+use crate::error::Result;
 use crate::{
     cipher::cipher_aead_aes_gcm::*, cipher::cipher_aes_cm_hmac_sha1::*, cipher::*, error::Error,
     option::*, protection_profile::*,
 };
 
-use anyhow::Result;
 use std::collections::HashMap;
 use util::replay_detector::*;
 
@@ -124,9 +124,9 @@ impl Context {
         let salt_len = profile.salt_len();
 
         if master_key.len() != key_len {
-            return Err(Error::SrtpMasterKeyLength(key_len, master_key.len()).into());
+            return Err(Error::SrtpMasterKeyLength(key_len, master_key.len()));
         } else if master_salt.len() != salt_len {
-            return Err(Error::SrtpSaltLength(salt_len, master_salt.len()).into());
+            return Err(Error::SrtpSaltLength(salt_len, master_salt.len()));
         }
 
         let cipher: Box<dyn Cipher + Send> = match profile {
